#ifndef __SP_ITEM_UPDATE_CNS_H__
#define __SP_ITEM_UPDATE_CNS_H__
#include <forward.h>

void sp_item_update_cns(SPItem &item, SPDesktop const &desktop);


#endif /* !__SP_ITEM_UPDATE_CNS_H__ */

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
